import { EventEmitter, Directive, ElementRef, NgZone, Input, Output, NgModule } from '@angular/core';

class BaseMorrisChartDirective {
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.clickChart = new EventEmitter();
        this.window = window;
    }
    ngAfterViewInit() {
        if (!this.window.Morris) {
            throw new Error('Please include node_modules/morris.js/morris.js');
        }
        else {
            this.morrisConfig = Object.assign({
                element: this.elementRef.nativeElement,
                data: this.data,
            }, this.options);
            this.ngZone.runOutsideAngular(() => {
                this.chartInstance = new this.window.Morris[this.mkMorrisJs](this.morrisConfig);
                this.chartInstance.on('click', (index, row) => {
                    this.clickChart.emit({ event, index, row });
                });
            });
        }
    }
    ngOnChanges(changes) {
        if ((changes.data && !changes.data.firstChange) || (changes.options && !changes.options.firstChange)) {
            Object.assign(this.chartInstance.options, this.options);
            this.ngZone.runOutsideAngular(() => this.chartInstance.setData(this.data));
        }
    }
    ngOnDestroy() {
        var _a, _b;
        if (((_b = (_a = this.chartInstance) === null || _a === void 0 ? void 0 : _a.el) === null || _b === void 0 ? void 0 : _b.empty) instanceof Function) {
            this.chartInstance.el.empty();
        }
    }
}
BaseMorrisChartDirective.decorators = [
    { type: Directive }
];
BaseMorrisChartDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone }
];
BaseMorrisChartDirective.propDecorators = {
    mkMorrisJs: [{ type: Input }],
    clickChart: [{ type: Output }]
};
class MorrisLineChartDirective extends BaseMorrisChartDirective {
}
MorrisLineChartDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mkMorrisJs="Line"]',
            },] }
];
MorrisLineChartDirective.propDecorators = {
    options: [{ type: Input }],
    data: [{ type: Input }]
};
class MorrisBarChartDirective extends BaseMorrisChartDirective {
}
MorrisBarChartDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mkMorrisJs="Bar"]',
            },] }
];
MorrisBarChartDirective.propDecorators = {
    options: [{ type: Input }],
    data: [{ type: Input }]
};
class MorrisDonutChartDirective extends BaseMorrisChartDirective {
}
MorrisDonutChartDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mkMorrisJs="Donut"]',
            },] }
];
MorrisDonutChartDirective.propDecorators = {
    options: [{ type: Input }],
    data: [{ type: Input }]
};
class MorrisAreaChartDirective extends BaseMorrisChartDirective {
}
MorrisAreaChartDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mkMorrisJs="Area"]',
            },] }
];
MorrisAreaChartDirective.propDecorators = {
    options: [{ type: Input }],
    data: [{ type: Input }]
};

class MorrisJsModule {
}
MorrisJsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MorrisLineChartDirective, MorrisAreaChartDirective, MorrisBarChartDirective, MorrisDonutChartDirective],
                exports: [MorrisLineChartDirective, MorrisAreaChartDirective, MorrisBarChartDirective, MorrisDonutChartDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { BaseMorrisChartDirective, MorrisAreaChartDirective, MorrisBarChartDirective, MorrisDonutChartDirective, MorrisJsModule, MorrisLineChartDirective };
//# sourceMappingURL=angular-morris-js.js.map
